@@ -13,7 +13,8 @@
 
 #include <gst/gst.h>
 #include <gst/interfaces/xoverlay.h>
-//#include <gst/interfaces/photography.h>
+#include <gst/interfaces/photography.h>
+#include <gst/interfaces/photography-enumtypes.h>
 #include "glib.h"
 
 #include <QTimer>
@@ -68,26 +69,53 @@ void CameraWidget::initialize()
 
 void CameraWidget::on_ButtonPicture_clicked()
 {
-  //  m_process.startDetached(" gst-launch v4l2camsrc device=/dev/video0 num-buffers=1 ! dspjpegenc ! filesink location=/usr/share/doc/poza.jpg");
     gst_element_set_state (pipeline, GST_STATE_NULL);
-
+    GstElement *picPipeline;
+    picPipeline = gst_pipeline_new ("pipeline");
     QProcess process;
 
-    process.startDetached(" gst-launch v4l2src device=/dev/video0 num-buffers=1 ! dspjpegenc ! filesink location=/home/opt/phototranslator-alpha/poza.jpg");
+ // process.startDetached(" gst-launch v4l2src device=/dev/video0 num-buffers=1 ! dspjpegenc ! filesink location=/home/opt/phototranslator-alpha/poza.jpg");
 
+    GstElement *src = gst_element_factory_make("v4l2src",NULL);
+
+    g_object_set(G_OBJECT(src),
+                 "num-buffers", "1 ",
+                  NULL);
+
+    GstElement *ffmpegcolorspace = gst_element_factory_make("ffmpegcolorspace",NULL);
+
+    GstElement *jpeg = gst_element_factory_make("dspjpegenc",NULL);
+
+    GstElement *filesink = gst_element_factory_make("filesink",NULL);
+
+    g_object_set(G_OBJECT(filesink),
+                "location", "/usr/share/doc/poza.jpg",
+                NULL);
+
+    gst_bin_add_many (GST_BIN (picPipeline), src, ffmpegcolorspace, jpeg,filesink, NULL);
+
+    gst_element_link_many(src,ffmpegcolorspace, jpeg,filesink, NULL);
+
+    gst_element_set_state(picPipeline, GST_STATE_PAUSED);
+
+    gst_photography_set_white_balance_mode(GST_PHOTOGRAPHY(picPipeline), GST_PHOTOGRAPHY_WB_MODE_DAYLIGHT);
+    gst_photography_set_colour_tone_mode(GST_PHOTOGRAPHY(picPipeline), GST_PHOTOGRAPHY_COLOUR_TONE_MODE_NATURAL);
+    gst_photography_set_autofocus(GST_PHOTOGRAPHY(picPipeline), true);
+
+    gst_element_set_state (picPipeline, GST_STATE_PLAYING);
+    //---
     sleep(3);
- //   QString strFile = "/usr/share/doc/poza.jpg";
-    QString strFile = "/home/opt/phototranslator-alpha/poza.jpg";
+    QString strFile = "/usr/share/doc/poza.jpg";
+  //QString strFile = "/home/user/MyDocs/.images/poza.jpg";
 
     // Show image view
     View_Image* viewImage = new View_Image(m_context, this);
-
     viewImage->show();
     viewImage->initialize(strFile);
 
-    process.close();
-
     process.startDetached("rm /home/opt/phototranslator-alpha/poza.jpg");
+    gst_element_set_state (picPipeline, GST_STATE_NULL);
+
 }
 
 bool CameraWidget::event( QEvent * myEvent )
